@@ -1,7 +1,7 @@
 package App::IndonesianFinanceUtils;
 
-our $DATE = '2016-10-14'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2021-02-01'; # DATE
+our $VERSION = '0.080'; # VERSION
 
 1;
 # ABSTRACT: CLIs related to Indonesian finance
@@ -18,7 +18,7 @@ App::IndonesianFinanceUtils - CLIs related to Indonesian finance
 
 =head1 VERSION
 
-This document describes version 0.07 of App::IndonesianFinanceUtils (from Perl distribution App-IndonesianFinanceUtils), released on 2016-10-14.
+This document describes version 0.080 of App::IndonesianFinanceUtils (from Perl distribution App-IndonesianFinanceUtils), released on 2021-02-01.
 
 =head1
 
@@ -26,24 +26,24 @@ This distribution contains several CLI's related to Indonesian finance:
 
 =over
 
-=item * L<convert-currency-using-gmc>
+=item * L<convert-currency-using-bca>
 
-=item * L<convert-currency-using-klikbca>
+=item * L<convert-currency-using-gmc>
 
 =item * L<get-jisdor-rates>
 
+=item * L<get-ksei-sec-ownership-url>
+
+=item * L<get-usd-idr-rate-from-bca>
+
 =item * L<get-usd-idr-rate-from-gmc>
 
-=item * L<get-usd-idr-rate-from-klikbca>
+=item * L<list-currency-exchange-rates-from-bca>
 
 =item * L<list-currency-exchange-rates-from-gmc>
 
-=item * L<list-currency-exchange-rates-from-klikbca>
-
 =back
 
-
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-IndonesianFinanceUtils>.
@@ -54,7 +54,7 @@ Source repository is at L<https://github.com/perlancar/perl-App-IndonesianFinanc
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-IndonesianFinanceUtils>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-IndonesianFinanceUtils/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -70,7 +70,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
